@@ -18,7 +18,9 @@ use std::path::PathBuf;
 
 /// CLI Parser.
 #[derive(Parser)]
-#[clap(version, about, long_about = None)]
+#[clap(version, about, long_about = None, arg_required_else_help = true)]
+#[clap(after_help = "Documentation: https://lib.rs/crates/xshe\n\
+GitHub: https://github.com/superatomic/xshe")]
 pub(crate) struct Cli {
     #[clap(arg_enum)]
     #[clap(help = "The shell to generate a script")]
@@ -29,8 +31,14 @@ pub(crate) struct Cli {
     #[clap(long_help = "Specifies a custom location to read from. \n\
      This defaults to $XDG_CONFIG_HOME, or ~/.config if not set. \n\
      \n\
-     The file must be in TOML format <https://toml.io/en/>.")]
+     The file must be in TOML format (https://toml.io/en/).")]
     pub file: Option<PathBuf>,
+
+    #[clap(short, long, value_name = "TOML")]
+    #[clap(help = "Directly specify TOML to parse", conflicts_with = "file")]
+    #[clap(long_help = "Directly specify TOML to parse. \n\
+     The passed string must be in TOML format (https://toml.io/en/).")]
+    pub toml: Option<String>,
 }
 
 /// Enum of every supported shell.
